
/* Generated data (by pika-mkenums) */

#include "stamp-tools-enums.h"
#include "config.h"
#include <gio/gio.h>
#include "libpikabase/pikabase.h"
#include "core/core-enums.h"
#include "tools-enums.h"
#include "pika-intl.h"

/* enumerations from "tools-enums.h" */
GType
pika_bucket_fill_area_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_BUCKET_FILL_SELECTION, "PIKA_BUCKET_FILL_SELECTION", "selection" },
    { PIKA_BUCKET_FILL_SIMILAR_COLORS, "PIKA_BUCKET_FILL_SIMILAR_COLORS", "similar-colors" },
    { PIKA_BUCKET_FILL_LINE_ART, "PIKA_BUCKET_FILL_LINE_ART", "line-art" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_BUCKET_FILL_SELECTION, NC_("bucket-fill-area", "Fill whole selection"), NULL },
    { PIKA_BUCKET_FILL_SIMILAR_COLORS, NC_("bucket-fill-area", "Fill similar colors"), NULL },
    { PIKA_BUCKET_FILL_LINE_ART, NC_("bucket-fill-area", "Fill by line art detection"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaBucketFillArea", values);
      pika_type_set_translation_context (type, "bucket-fill-area");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_line_art_source_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_LINE_ART_SOURCE_SAMPLE_MERGED, "PIKA_LINE_ART_SOURCE_SAMPLE_MERGED", "sample-merged" },
    { PIKA_LINE_ART_SOURCE_ACTIVE_LAYER, "PIKA_LINE_ART_SOURCE_ACTIVE_LAYER", "active-layer" },
    { PIKA_LINE_ART_SOURCE_LOWER_LAYER, "PIKA_LINE_ART_SOURCE_LOWER_LAYER", "lower-layer" },
    { PIKA_LINE_ART_SOURCE_UPPER_LAYER, "PIKA_LINE_ART_SOURCE_UPPER_LAYER", "upper-layer" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_LINE_ART_SOURCE_SAMPLE_MERGED, NC_("line-art-source", "All visible layers"), NULL },
    { PIKA_LINE_ART_SOURCE_ACTIVE_LAYER, NC_("line-art-source", "Selected layer"), NULL },
    { PIKA_LINE_ART_SOURCE_LOWER_LAYER, NC_("line-art-source", "Layer below the selected one"), NULL },
    { PIKA_LINE_ART_SOURCE_UPPER_LAYER, NC_("line-art-source", "Layer above the selected one"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaLineArtSource", values);
      pika_type_set_translation_context (type, "line-art-source");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_rect_select_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_RECT_SELECT_MODE_FREE, "PIKA_RECT_SELECT_MODE_FREE", "free" },
    { PIKA_RECT_SELECT_MODE_FIXED_SIZE, "PIKA_RECT_SELECT_MODE_FIXED_SIZE", "fixed-size" },
    { PIKA_RECT_SELECT_MODE_FIXED_RATIO, "PIKA_RECT_SELECT_MODE_FIXED_RATIO", "fixed-ratio" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_RECT_SELECT_MODE_FREE, NC_("rect-select-mode", "Free select"), NULL },
    { PIKA_RECT_SELECT_MODE_FIXED_SIZE, NC_("rect-select-mode", "Fixed size"), NULL },
    { PIKA_RECT_SELECT_MODE_FIXED_RATIO, NC_("rect-select-mode", "Fixed aspect ratio"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaRectSelectMode", values);
      pika_type_set_translation_context (type, "rect-select-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_transform_type_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_TRANSFORM_TYPE_LAYER, "PIKA_TRANSFORM_TYPE_LAYER", "layer" },
    { PIKA_TRANSFORM_TYPE_SELECTION, "PIKA_TRANSFORM_TYPE_SELECTION", "selection" },
    { PIKA_TRANSFORM_TYPE_PATH, "PIKA_TRANSFORM_TYPE_PATH", "path" },
    { PIKA_TRANSFORM_TYPE_IMAGE, "PIKA_TRANSFORM_TYPE_IMAGE", "image" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_TRANSFORM_TYPE_LAYER, NC_("transform-type", "Layer"), NULL },
    { PIKA_TRANSFORM_TYPE_SELECTION, NC_("transform-type", "Selection"), NULL },
    { PIKA_TRANSFORM_TYPE_PATH, NC_("transform-type", "Path"), NULL },
    { PIKA_TRANSFORM_TYPE_IMAGE, NC_("transform-type", "Image"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaTransformType", values);
      pika_type_set_translation_context (type, "transform-type");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_tool_action_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_TOOL_ACTION_PAUSE, "PIKA_TOOL_ACTION_PAUSE", "pause" },
    { PIKA_TOOL_ACTION_RESUME, "PIKA_TOOL_ACTION_RESUME", "resume" },
    { PIKA_TOOL_ACTION_HALT, "PIKA_TOOL_ACTION_HALT", "halt" },
    { PIKA_TOOL_ACTION_COMMIT, "PIKA_TOOL_ACTION_COMMIT", "commit" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_TOOL_ACTION_PAUSE, "PIKA_TOOL_ACTION_PAUSE", NULL },
    { PIKA_TOOL_ACTION_RESUME, "PIKA_TOOL_ACTION_RESUME", NULL },
    { PIKA_TOOL_ACTION_HALT, "PIKA_TOOL_ACTION_HALT", NULL },
    { PIKA_TOOL_ACTION_COMMIT, "PIKA_TOOL_ACTION_COMMIT", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaToolAction", values);
      pika_type_set_translation_context (type, "tool-action");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_tool_active_modifiers_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_TOOL_ACTIVE_MODIFIERS_OFF, "PIKA_TOOL_ACTIVE_MODIFIERS_OFF", "off" },
    { PIKA_TOOL_ACTIVE_MODIFIERS_SAME, "PIKA_TOOL_ACTIVE_MODIFIERS_SAME", "same" },
    { PIKA_TOOL_ACTIVE_MODIFIERS_SEPARATE, "PIKA_TOOL_ACTIVE_MODIFIERS_SEPARATE", "separate" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_TOOL_ACTIVE_MODIFIERS_OFF, "PIKA_TOOL_ACTIVE_MODIFIERS_OFF", NULL },
    { PIKA_TOOL_ACTIVE_MODIFIERS_SAME, "PIKA_TOOL_ACTIVE_MODIFIERS_SAME", NULL },
    { PIKA_TOOL_ACTIVE_MODIFIERS_SEPARATE, "PIKA_TOOL_ACTIVE_MODIFIERS_SEPARATE", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaToolActiveModifiers", values);
      pika_type_set_translation_context (type, "tool-active-modifiers");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_matting_draw_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_MATTING_DRAW_MODE_FOREGROUND, "PIKA_MATTING_DRAW_MODE_FOREGROUND", "foreground" },
    { PIKA_MATTING_DRAW_MODE_BACKGROUND, "PIKA_MATTING_DRAW_MODE_BACKGROUND", "background" },
    { PIKA_MATTING_DRAW_MODE_UNKNOWN, "PIKA_MATTING_DRAW_MODE_UNKNOWN", "unknown" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_MATTING_DRAW_MODE_FOREGROUND, NC_("matting-draw-mode", "Draw foreground"), NULL },
    { PIKA_MATTING_DRAW_MODE_BACKGROUND, NC_("matting-draw-mode", "Draw background"), NULL },
    { PIKA_MATTING_DRAW_MODE_UNKNOWN, NC_("matting-draw-mode", "Draw unknown"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaMattingDrawMode", values);
      pika_type_set_translation_context (type, "matting-draw-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_matting_preview_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_MATTING_PREVIEW_MODE_ON_COLOR, "PIKA_MATTING_PREVIEW_MODE_ON_COLOR", "on-color" },
    { PIKA_MATTING_PREVIEW_MODE_GRAYSCALE, "PIKA_MATTING_PREVIEW_MODE_GRAYSCALE", "grayscale" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_MATTING_PREVIEW_MODE_ON_COLOR, NC_("matting-preview-mode", "Color"), NULL },
    { PIKA_MATTING_PREVIEW_MODE_GRAYSCALE, NC_("matting-preview-mode", "Grayscale"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaMattingPreviewMode", values);
      pika_type_set_translation_context (type, "matting-preview-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_transform_3d_lens_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_TRANSFORM_3D_LENS_MODE_FOCAL_LENGTH, "PIKA_TRANSFORM_3D_LENS_MODE_FOCAL_LENGTH", "focal-length" },
    { PIKA_TRANSFORM_3D_LENS_MODE_FOV_IMAGE, "PIKA_TRANSFORM_3D_LENS_MODE_FOV_IMAGE", "fov-image" },
    { PIKA_TRANSFORM_3D_LENS_MODE_FOV_ITEM, "PIKA_TRANSFORM_3D_LENS_MODE_FOV_ITEM", "fov-item" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_TRANSFORM_3D_LENS_MODE_FOCAL_LENGTH, NC_("3-dtransform-lens-mode", "Focal length"), NULL },
    { PIKA_TRANSFORM_3D_LENS_MODE_FOV_IMAGE, NC_("3-dtransform-lens-mode", "Field of view (relative to image)"), NULL },
    /* Translators: this is an abbreviated version of "Field of view (relative to image)".
       Keep it short. */
    { PIKA_TRANSFORM_3D_LENS_MODE_FOV_IMAGE, NC_("3-dtransform-lens-mode", "FOV (image)"), NULL },
    { PIKA_TRANSFORM_3D_LENS_MODE_FOV_ITEM, NC_("3-dtransform-lens-mode", "Field of view (relative to item)"), NULL },
    /* Translators: this is an abbreviated version of "Field of view (relative to item)".
       Keep it short. */
    { PIKA_TRANSFORM_3D_LENS_MODE_FOV_ITEM, NC_("3-dtransform-lens-mode", "FOV (item)"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("Pika3DTransformLensMode", values);
      pika_type_set_translation_context (type, "3-dtransform-lens-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_warp_behavior_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_WARP_BEHAVIOR_MOVE, "PIKA_WARP_BEHAVIOR_MOVE", "move" },
    { PIKA_WARP_BEHAVIOR_GROW, "PIKA_WARP_BEHAVIOR_GROW", "grow" },
    { PIKA_WARP_BEHAVIOR_SHRINK, "PIKA_WARP_BEHAVIOR_SHRINK", "shrink" },
    { PIKA_WARP_BEHAVIOR_SWIRL_CW, "PIKA_WARP_BEHAVIOR_SWIRL_CW", "swirl-cw" },
    { PIKA_WARP_BEHAVIOR_SWIRL_CCW, "PIKA_WARP_BEHAVIOR_SWIRL_CCW", "swirl-ccw" },
    { PIKA_WARP_BEHAVIOR_ERASE, "PIKA_WARP_BEHAVIOR_ERASE", "erase" },
    { PIKA_WARP_BEHAVIOR_SMOOTH, "PIKA_WARP_BEHAVIOR_SMOOTH", "smooth" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_WARP_BEHAVIOR_MOVE, NC_("warp-behavior", "Move pixels"), NULL },
    { PIKA_WARP_BEHAVIOR_GROW, NC_("warp-behavior", "Grow area"), NULL },
    { PIKA_WARP_BEHAVIOR_SHRINK, NC_("warp-behavior", "Shrink area"), NULL },
    { PIKA_WARP_BEHAVIOR_SWIRL_CW, NC_("warp-behavior", "Swirl clockwise"), NULL },
    { PIKA_WARP_BEHAVIOR_SWIRL_CCW, NC_("warp-behavior", "Swirl counter-clockwise"), NULL },
    { PIKA_WARP_BEHAVIOR_ERASE, NC_("warp-behavior", "Erase warping"), NULL },
    { PIKA_WARP_BEHAVIOR_SMOOTH, NC_("warp-behavior", "Smooth warping"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaWarpBehavior", values);
      pika_type_set_translation_context (type, "warp-behavior");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_paint_select_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_PAINT_SELECT_MODE_ADD, "PIKA_PAINT_SELECT_MODE_ADD", "add" },
    { PIKA_PAINT_SELECT_MODE_SUBTRACT, "PIKA_PAINT_SELECT_MODE_SUBTRACT", "subtract" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_PAINT_SELECT_MODE_ADD, NC_("paint-select-mode", "Add to selection"), NULL },
    { PIKA_PAINT_SELECT_MODE_SUBTRACT, NC_("paint-select-mode", "Subtract from selection"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaPaintSelectMode", values);
      pika_type_set_translation_context (type, "paint-select-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}


/* Generated data ends here */

